==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ContextPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyRuleConditionPlatform;
import com.okta.sdk.resource.model.DevicePolicyTrustLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ContextPolicyRuleCondition
 */
@JsonPropertyOrder({ ContextPolicyRuleCondition.JSON_PROPERTY_MIGRATED,
        ContextPolicyRuleCondition.JSON_PROPERTY_PLATFORM, ContextPolicyRuleCondition.JSON_PROPERTY_ROOTED,
        ContextPolicyRuleCondition.JSON_PROPERTY_TRUST_LEVEL, ContextPolicyRuleCondition.JSON_PROPERTY_EXPRESSION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ContextPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MIGRATED = "migrated";
    private Boolean migrated;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private DevicePolicyRuleConditionPlatform platform;

    public static final String JSON_PROPERTY_ROOTED = "rooted";
    private Boolean rooted;

    public static final String JSON_PROPERTY_TRUST_LEVEL = "trustLevel";
    private DevicePolicyTrustLevel trustLevel;

    public static final String JSON_PROPERTY_EXPRESSION = "expression";
    private String expression;

    public ContextPolicyRuleCondition() {
    }

    public ContextPolicyRuleCondition migrated(Boolean migrated) {

        this.migrated = migrated;
        return this;
    }

    /**
     * Get migrated
     *
     * @return migrated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getMigrated() {
        return migrated;
    }

    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMigrated(Boolean migrated) {
        this.migrated = migrated;
    }

    public ContextPolicyRuleCondition platform(DevicePolicyRuleConditionPlatform platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyRuleConditionPlatform getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(DevicePolicyRuleConditionPlatform platform) {
        this.platform = platform;
    }

    public ContextPolicyRuleCondition rooted(Boolean rooted) {

        this.rooted = rooted;
        return this;
    }

    /**
     * Get rooted
     *
     * @return rooted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRooted() {
        return rooted;
    }

    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRooted(Boolean rooted) {
        this.rooted = rooted;
    }

    public ContextPolicyRuleCondition trustLevel(DevicePolicyTrustLevel trustLevel) {

        this.trustLevel = trustLevel;
        return this;
    }

    /**
     * Get trustLevel
     *
     * @return trustLevel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyTrustLevel getTrustLevel() {
        return trustLevel;
    }

    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrustLevel(DevicePolicyTrustLevel trustLevel) {
        this.trustLevel = trustLevel;
    }

    public ContextPolicyRuleCondition expression(String expression) {

        this.expression = expression;
        return this;
    }

    /**
     * Get expression
     *
     * @return expression
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExpression() {
        return expression;
    }

    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExpression(String expression) {
        this.expression = expression;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ContextPolicyRuleCondition contextPolicyRuleCondition = (ContextPolicyRuleCondition) o;
        return Objects.equals(this.migrated, contextPolicyRuleCondition.migrated)
                && Objects.equals(this.platform, contextPolicyRuleCondition.platform)
                && Objects.equals(this.rooted, contextPolicyRuleCondition.rooted)
                && Objects.equals(this.trustLevel, contextPolicyRuleCondition.trustLevel)
                && Objects.equals(this.expression, contextPolicyRuleCondition.expression);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(migrated, platform, rooted, trustLevel, expression);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ContextPolicyRuleCondition {\n");
        sb.append("    migrated: ").append(toIndentedString(migrated)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("    rooted: ").append(toIndentedString(rooted)).append("\n");
        sb.append("    trustLevel: ").append(toIndentedString(trustLevel)).append("\n");
        sb.append("    expression: ").append(toIndentedString(expression)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ContextPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyRuleConditionPlatform;
import com.okta.sdk.resource.model.DevicePolicyTrustLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ContextPolicyRuleCondition
 */
@JsonPropertyOrder({ ContextPolicyRuleCondition.JSON_PROPERTY_MIGRATED,
        ContextPolicyRuleCondition.JSON_PROPERTY_PLATFORM, ContextPolicyRuleCondition.JSON_PROPERTY_ROOTED,
        ContextPolicyRuleCondition.JSON_PROPERTY_TRUST_LEVEL, ContextPolicyRuleCondition.JSON_PROPERTY_EXPRESSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ContextPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MIGRATED = "migrated";
    private Boolean migrated;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private DevicePolicyRuleConditionPlatform platform;

    public static final String JSON_PROPERTY_ROOTED = "rooted";
    private Boolean rooted;

    public static final String JSON_PROPERTY_TRUST_LEVEL = "trustLevel";
    private DevicePolicyTrustLevel trustLevel;

    public static final String JSON_PROPERTY_EXPRESSION = "expression";
    private String expression;

    public ContextPolicyRuleCondition() {
    }

    public ContextPolicyRuleCondition migrated(Boolean migrated) {

        this.migrated = migrated;
        return this;
    }

    /**
     * Get migrated
     *
     * @return migrated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getMigrated() {
        return migrated;
    }

    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMigrated(Boolean migrated) {
        this.migrated = migrated;
    }

    public ContextPolicyRuleCondition platform(DevicePolicyRuleConditionPlatform platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyRuleConditionPlatform getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(DevicePolicyRuleConditionPlatform platform) {
        this.platform = platform;
    }

    public ContextPolicyRuleCondition rooted(Boolean rooted) {

        this.rooted = rooted;
        return this;
    }

    /**
     * Get rooted
     *
     * @return rooted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRooted() {
        return rooted;
    }

    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRooted(Boolean rooted) {
        this.rooted = rooted;
    }

    public ContextPolicyRuleCondition trustLevel(DevicePolicyTrustLevel trustLevel) {

        this.trustLevel = trustLevel;
        return this;
    }

    /**
     * Get trustLevel
     *
     * @return trustLevel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyTrustLevel getTrustLevel() {
        return trustLevel;
    }

    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrustLevel(DevicePolicyTrustLevel trustLevel) {
        this.trustLevel = trustLevel;
    }

    public ContextPolicyRuleCondition expression(String expression) {

        this.expression = expression;
        return this;
    }

    /**
     * Get expression
     *
     * @return expression
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExpression() {
        return expression;
    }

    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExpression(String expression) {
        this.expression = expression;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ContextPolicyRuleCondition contextPolicyRuleCondition = (ContextPolicyRuleCondition) o;
        return Objects.equals(this.migrated, contextPolicyRuleCondition.migrated)
                && Objects.equals(this.platform, contextPolicyRuleCondition.platform)
                && Objects.equals(this.rooted, contextPolicyRuleCondition.rooted)
                && Objects.equals(this.trustLevel, contextPolicyRuleCondition.trustLevel)
                && Objects.equals(this.expression, contextPolicyRuleCondition.expression);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(migrated, platform, rooted, trustLevel, expression);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ContextPolicyRuleCondition {\n");
        sb.append("    migrated: ").append(toIndentedString(migrated)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("    rooted: ").append(toIndentedString(rooted)).append("\n");
        sb.append("    trustLevel: ").append(toIndentedString(trustLevel)).append("\n");
        sb.append("    expression: ").append(toIndentedString(expression)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
